# The one and the only real True value generator.

# Example:
```python
from the_true import THE_TRUE
from sys import setrecursionlimit

setrecursionlimit(100000)

while THE_TRUE():
    print("Hello world")
```